@@ -21,7 +21,7 @@ from shutil import rmtree
 from time import sleep
 from impacket.ntlm import compute_lmhash, compute_nthash
 from logging import DEBUG, getLogger
-from os import path
+from os import path, getenv
 from subprocess import Popen
 from six.moves import configparser, socketserver
 from threading import enumerate as threading_enumerate
@@ -32,27 +32,22 @@ from uuid import uuid4
 
 
 class QSMBServer():
-    def __init__(self, ip=None, port=None, username=None, password=None, folders=None, mocking=False, config=''):
+    def __init__(self, **kwargs):
         self.auto_disabled = None
-        self.mocking = mocking or ''
         self.process = None
         self.uuid = 'honeypotslogger' + '_' + __class__.__name__ + '_' + str(uuid4())[:8]
-        self.config = config
-        self.ip = None
-        self.port = None
-        self.username = None
-        self.password = None
-        self.folders = None
-        if config:
-            self.logs = setup_logger(__class__.__name__, self.uuid, config)
-            set_local_vars(self, config)
+        self.folders = ''
+        self.config = kwargs.get('config', '')
+        if self.config:
+            self.logs = setup_logger(__class__.__name__, self.uuid, self.config)
+            set_local_vars(self, self.config)
         else:
             self.logs = setup_logger(__class__.__name__, self.uuid, None)
-        self.ip = ip or self.ip or '0.0.0.0'
-        self.port = port or self.port or 445
-        self.username = username or self.username or 'test'
-        self.password = password or self.password or 'test'
-        self.folders = folders or self.folders or ''
+        self.ip = kwargs.get('ip', None) or (hasattr(self, 'ip') and self.ip) or '0.0.0.0'
+        self.port = kwargs.get('port', None) or (hasattr(self, 'port') and self.port) or 445
+        self.username = kwargs.get('username', None) or (hasattr(self, 'username') and self.username) or 'test'
+        self.password = kwargs.get('password', None) or (hasattr(self, 'password') and self.password) or 'test'
+        self.options = kwargs.get('options', '') or (hasattr(self, 'options') and self.options) or getenv('HONEYPOTS_OPTIONS', '') or ''
         self.disable_logger()
 
     def disable_logger(self):
@@ -69,13 +64,12 @@ class QSMBServer():
                         ip = temp.split('_')[1]
                         port = temp.split('_')[2]
                         if 'Incoming connection' in message.strip() or 'AUTHENTICATE_MESSAGE' in message.strip() or 'authenticated successfully' in message.strip():
-                            _q_s.logs.info({'server': 'smb_server', 'action': 'connection', 'msg': message.strip(), 'src_ip': ip, 'src_port': port, 'dest_ip': _q_s.ip, 'dest_port': _q_s.port})
+                            _q_s.logs.info({'server': 'smb_server', 'action': 'connection', 'data': message.strip(), 'src_ip': ip, 'src_port': port, 'dest_ip': _q_s.ip, 'dest_port': _q_s.port})
                         elif ':4141414141414141:' in message.strip():
                             parsed = message.strip().split(':')
                             if len(parsed) > 2:
                                 _q_s.logs.info({'server': 'smb_server', 'action': 'login', 'workstation': parsed[0], 'test': parsed[1], 'src_ip': ip, 'src_port': port, 'dest_ip': _q_s.ip, 'dest_port': _q_s.port})
                 except Exception as e:
-                    print(e)
                     pass
 
         class SMBSERVERHandler(smbserver.SMBSERVERHandler):
@@ -144,11 +138,11 @@ class QSMBServer():
                 run = True
 
             if run:
-                self.process = Popen(['python3', path.realpath(__file__), '--custom', '--ip', str(self.ip), '--port', str(self.port), '--username', str(self.username), '--password', str(self.password), '--folders', str(self.folders), '--mocking', str(self.mocking), '--config', str(self.config), '--uuid', str(self.uuid)])
+                self.process = Popen(['python3', path.realpath(__file__), '--custom', '--ip', str(self.ip), '--port', str(self.port), '--username', str(self.username), '--password', str(self.password), '--options', str(self.options), '--config', str(self.config), '--uuid', str(self.uuid)])
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info({'server': 'smb_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'username': self.username, 'password': self.password, 'folders': str(self.folders), 'dest_ip': self.ip, 'dest_port': self.port})
+            self.logs.info({'server': 'smb_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'username': self.username, 'password': self.password, 'dest_ip': self.ip, 'dest_port': self.port})
 
             if status == 'success':
                 return True
@@ -183,5 +177,5 @@ if __name__ == '__main__':
 
     parsed = server_arguments()
     if parsed.docker or parsed.aws or parsed.custom:
-        qsmbserver = QSMBServer(ip=parsed.ip, port=parsed.port, username=parsed.username, password=parsed.password, folders=parsed.folders, mocking=parsed.mocking, config=parsed.config)
+        qsmbserver = QSMBServer(ip=parsed.ip, port=parsed.port, username=parsed.username, password=parsed.password, folders=parsed.folders, options=parsed.options, config=parsed.config)
         qsmbserver.run_server()
