@@ -15,32 +15,28 @@ filterwarnings(action='ignore', module='.*OpenSSL.*')
 
 from socketserver import TCPServer, StreamRequestHandler, ThreadingMixIn
 from struct import unpack
-from os import path
+from os import path, getenv
 from subprocess import Popen
 from honeypots.helper import check_if_server_is_running, close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, set_local_vars, setup_logger
 from uuid import uuid4
 
 
 class QSOCKS5Server():
-    def __init__(self, ip=None, port=None, username=None, password=None, mocking=False, config=''):
+    def __init__(self, **kwargs):
         self.auto_disabled = None
-        self.mocking = mocking or ''
         self.process = None
         self.uuid = 'honeypotslogger' + '_' + __class__.__name__ + '_' + str(uuid4())[:8]
-        self.ip = None
-        self.port = None
-        self.username = None
-        self.password = None
-        self.config = config
-        if config:
-            self.logs = setup_logger(__class__.__name__, self.uuid, config)
-            set_local_vars(self, config)
+        self.config = kwargs.get('config', '')
+        if self.config:
+            self.logs = setup_logger(__class__.__name__, self.uuid, self.config)
+            set_local_vars(self, self.config)
         else:
             self.logs = setup_logger(__class__.__name__, self.uuid, None)
-        self.ip = ip or self.ip or '0.0.0.0'
-        self.port = port or self.port or 1080
-        self.username = username or self.username or 'test'
-        self.password = password or self.password or 'test'
+        self.ip = kwargs.get('ip', None) or (hasattr(self, 'ip') and self.ip) or '0.0.0.0'
+        self.port = kwargs.get('port', None) or (hasattr(self, 'port') and self.port) or 1080
+        self.username = kwargs.get('username', None) or (hasattr(self, 'username') and self.username) or 'test'
+        self.password = kwargs.get('password', None) or (hasattr(self, 'password') and self.password) or 'test'
+        self.options = kwargs.get('options', '') or (hasattr(self, 'options') and self.options) or getenv('HONEYPOTS_OPTIONS', '') or ''
 
     def socks5_server_main(self):
         _q_s = self
@@ -95,7 +91,7 @@ class QSOCKS5Server():
                 run = True
 
             if run:
-                self.process = Popen(['python3', path.realpath(__file__), '--custom', '--ip', str(self.ip), '--port', str(self.port), '--username', str(self.username), '--password', str(self.password), '--mocking', str(self.mocking), '--config', str(self.config), '--uuid', str(self.uuid)])
+                self.process = Popen(['python3', path.realpath(__file__), '--custom', '--ip', str(self.ip), '--port', str(self.port), '--username', str(self.username), '--password', str(self.password), '--options', str(self.options), '--config', str(self.config), '--uuid', str(self.uuid)])
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
@@ -132,5 +128,5 @@ class QSOCKS5Server():
 if __name__ == '__main__':
     parsed = server_arguments()
     if parsed.docker or parsed.aws or parsed.custom:
-        QSOCKS5Server = QSOCKS5Server(ip=parsed.ip, port=parsed.port, username=parsed.username, password=parsed.password, mocking=parsed.mocking, config=parsed.config)
+        QSOCKS5Server = QSOCKS5Server(ip=parsed.ip, port=parsed.port, username=parsed.username, password=parsed.password, options=parsed.options, config=parsed.config)
         QSOCKS5Server.run_server()
